import {
  select,
  scaleLinear,
  scaleOrdinal,
  scaleSqrt,
  extent,
  min,
  max,
  axisLeft,
  axisBottom,
  symbols,
  symbol,
  transition,
} from 'd3';

export const scatterPlot = () => {
  let width = 960;
  let height = 500;
  let data = [];
  let xValue = [];
  let yValue = [];
  let margin = {
    top: 10,
    right: 20,
    bottom: 10,
    left: 20,
  };
  let size = 5;

  const my = (selection) => {
    const xScale = scaleLinear()
      .domain(
        extent(data, xValue) // [min(data, xValue), max(data, xValue)]
      )
      .range([margin.left, width - margin.right]);

    const yScale = scaleLinear()
      .domain([
        min(data, yValue),
        max(data, yValue),
      ])
      .range([
        height - margin.bottom,
        margin.top,
      ]);

    const marks = data.map((d) => ({
      x: xScale(xValue(d)),
      y: yScale(yValue(d)),
    }));

    const t = transition().duration(2000);

    selection
      .selectAll('circle')
      .data(marks)
      .join(
        (enter) =>
          enter
            .append('circle')
            .attr('cx', (d) => d.x)
            .attr('cy', (d) => d.y)
            .attr('r', 0)
            .call((enter) =>
              enter
                .transition(t)
                .attr('r', size)
            ),
        (update) =>
          update
            .attr('cx', (d) => d.x)
            .attr('cy', (d) => d.y)
      			.call(update => 
                  update.transition(t).attr('cx', d => d.x).attr('c')
              
            ),
        (exit) => exit.remove()
      );

    selection
      .selectAll('g.x-axis')
      .data([null])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(${0}, ${
          height - margin.bottom
        })`
      )
      .call(axisBottom(xScale));

    selection
      .selectAll('g.y-axis')
      .data([null])
      .join('g')
      .attr('class', 'x-axis')
      .attr(
        'transform',
        `translate(${margin.left}, ${0})`
      )
      .call(axisLeft(yScale));
  };

  my.width = function (_) {
    return arguments.length
      ? ((width = +_), my)
      : width;
  };

  my.height = function (_) {
    return arguments.length
      ? ((height = +_), my)
      : height;
  };

  my.data = function (_) {
    return arguments.length
      ? ((data = _), my)
      : data;
  };

  my.xValue = function (_) {
    return arguments.length
      ? ((xValue = _), my)
      : xValue;
  };

  my.yValue = function (_) {
    return arguments.length
      ? ((yValue = _), my)
      : yValue;
  };

  my.symbolValue = function (_) {
    return arguments.length
      ? ((symbolValue = _), my)
      : symbolValue;
  };

  my.margin = function (_) {
    return arguments.length
      ? ((margin = _), my)
      : margin;
  };

  my.size = function (_) {
    return arguments.length
      ? ((size = +_), my)
      : size;
  };

  return my;
};
